#ifndef FLASH_H_
#define FLASH_H_

typedef unsigned short uint16_t;

// digital masks
#define ERROR			0x01
#define REPLAY			0x02
#define	LAUNCHED		0x04
#define MAS_STAGING		0x08
#define MAS_SERVO		0x10
#define MC2_STAGING		0x20
#define MC2_SERVO		0x40

// analog masks (for extracting the appropriate bits)
#define ALTITUDE_MASK	0x0A

// access macros
#define GetAltitude(rec)		(rec.altitude & ALTITUDE_MASK)
#define GetLongAccel(rec)		((rec.longAccel << 2) | (rec.altitude >> 14))
#define GetVertAccel(rec)		((rec.vertAccel << 2) | ((rec.altitude >> 12) & 0x3))

#define SetAltitude(rec, alt)	rec.altitude = (rec.altitude & 0xFC00) | alt
#define SetLongAccel(rec, acc)	rec.longAccel = acc >> 2; rec.altitude ^= 0xC000; 
#define SetVertAccel(rec, acc)	

struct Record
{
	uint8_t digital;
		
	// analog flight data
	uint8_t longAccel;	// longitudinal acceleration (low 2 bits in altitude)
	uint8_t vertAccel;	// vertical acceleration [when flying] (low 2 bits in altitude)
	uint16_t altitude;	// altitude (in low 10 bits)
	uint8_t batt074;	// voltage of 7.4V battery
	uint8_t batt111;	// voltage of 11.1V battery
	uint8_t igniter;	// voltage at igniter output
};

#endif