#include <system.h>
#include "serial.h"

volatile bool sending = false;
unsigned char bitsSent = 0;
unsigned short buffer = 0;

void serialInit()
{
	trisio.SEROUT_PINNUM = 0; // make it an output
	SEROUT = 0; // quiescent line level is high
	
	// set up timer
	clear_bit(option_reg, T0CS); // TMR0 operates on internal clock
	clear_wdt();
	clear_bit(option_reg, PSA); // prescaler is assigned to TMR0
	
	// set prescaler to 000 (1:2)
	clear_bit(option_reg, PS2);
	clear_bit(option_reg, PS1);
	clear_bit(option_reg, PS0);
	
	// set up interrupts	
	set_bit(intcon, T0IE); // enable TMR0 interrupt
	set_bit(intcon, GIE);
}

void putch(char c)
{
	while (sending) // wait until the last byte was sent
		;
	
	//buffer = 0;
	buffer = ((unsigned short)c << 1) | 0xFE00;
	bitsSent = 0;
	sending = true;
}

void puts(const char * str)
{
	for (; *str != '\0'; ++str)
		putch(*str);
}

void interrupt( void )
{
	if (test_bit(intcon, T0IF))
	{
		clear_bit(intcon, T0IF);  //clear TMR0 overflow flag
		tmr0 = 58;
		
				
		if (sending)
		{
			if (test_bit(buffer, 0)) // if bit is set, send low.  if bit is not set, send high
			{
				SEROUT = 0;
			}
			else
			{
				SEROUT = 1;
			}
			
			buffer >>= 1;
			++bitsSent;
			if (bitsSent == 10)
				sending = false;
		}
	}
}